<?php

namespace KnitPay\Extensions\TourMaster;

use Pronamic\WordPress\Money\TaxedMoney;
use Pronamic\WordPress\Money\Parser as MoneyParser;
use Pronamic\WordPress\Pay\Payments\PaymentLines;
use Pronamic\WordPress\Pay\Payments\PaymentData as Pay_PaymentData;
use Pronamic\WordPress\Pay\Payments\Item;
use Pronamic\WordPress\Pay\Payments\Items;
use Pronamic\WordPress\Pay\Payments\PaymentDataInterface as Pronamic_Pay_PaymentDataInterface;

/**
 * Title: WordPress pay Tour Master payment data
 * Description:
 * Copyright: 2020 Knit Pay
 * Company: Knit Pay
 *
 * @author  knitpay
 * @since   2.1.0
 */
class PaymentData extends Pay_PaymentData {
	/**
	 * The Tour ID.
	 *
	 * @var int
	 */
	private $tid;

	/**
	 * Constructs and initializes an Give payment data object.
	 *
	 * @param int     $donation_id Donation ID.
	 * @param Gateway $gateway     Gateway.
	 */
	public function __construct( $tid, $gateway ) {
		parent::__construct();

		$this->booking_data = tourmaster_get_booking_data( array( 'id' => $tid ), array( 'single' => true ) );
		$this->billing_info = json_decode( $this->booking_data->billing_info );

		$this->tid     = $tid;
		$this->gateway = $gateway;
	}

	/**
	 * Get source indicator
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_source()
	 * @return string
	 */
	public function get_source() {
		return 'tourmaster';
	}

	/**
	 * Get source ID.
	 *
	 * @return int
	 */
	public function get_source_id() {
		return $this->tid;
	}

	/**
	 * Get title.
	 *
	 * @return string
	 */
	public function get_title() {
		return sprintf(
			/* translators: %s: order id */
			__( 'Tour Master Order %s', 'pronamic_ideal' ),
			$this->get_order_id()
		);
	}

	/**
	 * Get description
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_description()
	 * @return string
	 */
	public function get_description() {
		$description = tourmaster_get_option( 'payment', $this->gateway->id . '-payment-description' );

		if ( '' === $description ) {
			$description = $this->get_title();
		}

		$replacements = array(
			'{order_id}' => $this->get_order_id(),
		);

		return strtr( $description, $replacements );
	}

	/**
	 * Get order ID
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_order_id()
	 * @return string
	 */
	public function get_order_id() {
		return $this->tid;
	}

	/**
	 * Get items
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_items()
	 * @return Items
	 */
	public function get_items() {
	}

	public function get_amount() {
		$t_data = apply_filters( 'goodlayers_payment_get_transaction_data', array(), $this->tid, array( 'price' ) );

		if ( array_key_exists( 'deposit-price', $t_data['price'] ) && $t_data['price']['deposit-price'] ) {
			$price = $t_data['price']['deposit-price'];
		} else {
			$price = $t_data['price']['pay-amount'];
		}

		$amount = new TaxedMoney( $price, $this->get_currency_alphabetic_code() );
		return $amount;
	}

	public function get_telephone_number() {
		return $this->billing_info->phone;
	}

	/**
	 * Get currency
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_currency_alphabetic_code()
	 * @return string
	 */
	public function get_currency_alphabetic_code() {
		return tourmaster_get_option( 'payment', $this->gateway->id . '-currency' );
	}

	public function get_email() {
		return $this->billing_info->email;
	}

	public function get_first_name() {
		if ( isset( $this->billing_info->first_name ) ) {
			return $this->billing_info->first_name;
		}
	}

	public function get_last_name() {
		if ( isset( $this->billing_info->last_name ) ) {
			return $this->billing_info->last_name;
		}
	}

	public function get_customer_name() {
		return $this->billing_info->first_name . ' ' . $this->billing_info->last_name;
	}

	public function get_address() {
		$address = null;

		if ( isset( $this->billing_info->contact_address ) ) {
			$address = $this->billing_info->contact_address;
		}

		return $address;
	}

	/*
	public function get_city() {
		$city = null;

		return $city;
	}

	public function get_zip() {
		$zip = null;

		$user_info = give_get_payment_meta_user_info( $this->donation_id );

		if ( ! empty( $user_info['address'] ) ) {
			$zip = $user_info['address']['zip'];
		}

		return $zip;
	}*/

	/**
	 * Get normal return URL.
	 *
	 * @link https://github.com/woothemes/woocommerce/blob/v2.1.3/includes/abstracts/abstract-wc-payment-gateway.php#L52
	 * @return string
	 */
	public function get_normal_return_url() {
	}

	public function get_cancel_url() {
	}

	public function get_success_url() {
	}

	public function get_error_url() {
	}
}
